==> v1.0.4.zip: platformservice/ts/plugins.ts <==
// node native
import * as dns from 'dns';
import * as fs from 'fs';
import * as crypto from 'crypto';
import * as net from 'net';
import * as path from 'path';
import * as tls from 'tls';
import * as util from 'util';

export {
  dns,
  fs,
  crypto,
  net,
  path,
  tls,
  util,
}

// @serve.zone scope
import * as servezoneInterfaces from '@serve.zone/interfaces';

export {
  servezoneInterfaces
}

// @api.global scope
import * as typedrequest from '@api.global/typedrequest';
import * as typedserver from '@api.global/typedserver';
import * as typedsocket from '@api.global/typedsocket';

export {
  typedrequest,
  typedserver,
  typedsocket,
}

// @push.rocks scope
import * as projectinfo from '@push.rocks/projectinfo';
import * as qenv from '@push.rocks/qenv';
import * as smartdata from '@push.rocks/smartdata';
import * as smartfile from '@push.rocks/smartfile';
import * as smartlog from '@push.rocks/smartlog';
import * as smartmail from '@push.rocks/smartmail';
import * as smartpath from '@push.rocks/smartpath';
import * as smartpromise from '@push.rocks/smartpromise';
import * as smartrequest from '@push.rocks/smartrequest';
import * as smartrx from '@push.rocks/smartrx';

export { projectinfo, qenv, smartdata, smartfile, smartlog, smartmail, smartpath, smartpromise, smartrequest, smartrx };

// tsclass scope
import * as tsclass from '@tsclass/tsclass';

export {
  tsclass,
}

// third party
import * as mailauth from 'mailauth';
import { dkimSign } from 'mailauth/lib/dkim/sign.js';
import mailparser from 'mailparser';
import * as uuid from 'uuid';

export {
  mailauth,
  dkimSign,
  mailparser,
  uuid,
}

==> v2.3.1.zip: platformservice/ts/plugins.ts <==
// node native
import * as dns from 'dns';
import * as fs from 'fs';
import * as crypto from 'crypto';
import * as http from 'http';
import * as net from 'net';
import * as path from 'path';
import * as tls from 'tls';
import * as util from 'util';

export {
  dns,
  fs,
  crypto,
  http,
  net,
  path,
  tls,
  util,
}

// @serve.zone scope
import * as servezoneInterfaces from '@serve.zone/interfaces';

export {
  servezoneInterfaces
}

// @api.global scope
import * as typedrequest from '@api.global/typedrequest';
import * as typedserver from '@api.global/typedserver';
import * as typedsocket from '@api.global/typedsocket';

export {
  typedrequest,
  typedserver,
  typedsocket,
}

// @push.rocks scope
import * as projectinfo from '@push.rocks/projectinfo';
import * as qenv from '@push.rocks/qenv';
import * as smartdata from '@push.rocks/smartdata';
import * as smartdns from '@push.rocks/smartdns';
import * as smartfile from '@push.rocks/smartfile';
import * as smartlog from '@push.rocks/smartlog';
import * as smartmail from '@push.rocks/smartmail';
import * as smartpath from '@push.rocks/smartpath';
import * as smartproxy from '@push.rocks/smartproxy';
import * as smartpromise from '@push.rocks/smartpromise';
import * as smartrequest from '@push.rocks/smartrequest';
import * as smartrule from '@push.rocks/smartrule';
import * as smartrx from '@push.rocks/smartrx';

export { projectinfo, qenv, smartdata, smartdns, smartfile, smartlog, smartmail, smartpath, smartproxy, smartpromise, smartrequest, smartrule, smartrx };

// apiclient.xyz scope
import * as letterxpress from '@apiclient.xyz/letterxpress';

export {
  letterxpress,
}

// tsclass scope
import * as tsclass from '@tsclass/tsclass';

export {
  tsclass,
}

// third party
import * as mailauth from 'mailauth';
import { dkimSign } from 'mailauth/lib/dkim/sign.js';
import mailparser from 'mailparser';
import * as uuid from 'uuid';

export {
  mailauth,
  dkimSign,
  mailparser,
  uuid,
}
